@@ -114,9 +114,10 @@ dt_pivot <- function(DT, theby, theexp, percent.cutoff=0, value.name="value",
 #' into a category called "OTHER".
 #' The percent is a number out of 100
 #'
-#' The final row is a total count
+#' The final row is a total count.
 #'
-#' The quoted group-by variable must be a character or factor
+#' The quoted group-by variable must be a character or factor. If it is
+#' not, it will be temporarily converted into one and a warning is issued.
 #'
 #' @import data.table
 #'
@@ -155,6 +156,15 @@ dt_counts_and_percents <- function(DT, group_by_this, percent.cutoff=0,
 
   count <- NULL
 
+  # determine if casting to factor is necessary
+  if(!methods::is(DT[[group_by_this]], "character") &&
+     !methods::is(DT[[group_by_this]], "factor")) {
+    warning(sprintf("Column (%s) is not a factor (or character), %s",
+                    group_by_this, "copying DT and converting..."))
+    DT <- copy(DT)
+    DT[, (group_by_this):=as.factor(get(group_by_this))]
+  }
+
   tmp <- dt_pivot(DT, group_by_this, .N, percent.cutoff=percent.cutoff,
                   value.name="count", percent.name="percent")
   if(big.mark!=FALSE)
@@ -162,9 +172,6 @@ dt_counts_and_percents <- function(DT, group_by_this, percent.cutoff=0,
   tmp[]
 }
 
-
-
-
 # --------------------------------------------------------------- #
 
 #' Takes a data.frame and returns cleaned column names
@@ -202,7 +209,7 @@ dt_counts_and_percents <- function(DT, group_by_this, percent.cutoff=0,
 get_clean_names <- function(dat, lower=TRUE){
   thenames <- names(dat)
   nospace <- stringr::str_replace_all(thenames, "\\s+", "_")
-  nobad <- stringr::str_replace_all(nospace, "[^_A-Za-z1-9]", "_")
+  nobad <- stringr::str_replace_all(nospace, "[^_A-Za-z0-9]", "_")
   if(lower)
     nobad <- tolower(nobad)
   if(sum(duplicated(nobad))){
